<?php
/**
 * WHMCS Sample Payment Callback File
 *
 * This sample file demonstrates how a payment gateway callback should be
 * handled within WHMCS.
 *
 * It demonstrates verifying that the payment gateway module is active,
 * validating an Invoice ID, checking for the existence of a Transaction ID,
 * Logging the Transaction for debugging and Adding Payment to an Invoice.
 *
 * For more information, please refer to the online documentation.
 *
 * @see https://developers.whmcs.com/payment-gateways/callbacks/
 *
 * @copyright Copyright (c) WHMCS Limited 2017
 * @license http://www.whmcs.com/license/ WHMCS Eula
 */

// Require libraries needed for gateway module functions.
require_once __DIR__ . '/../../../init.php';
require_once __DIR__ . '/../../../includes/gatewayfunctions.php';
require_once __DIR__ . '/../../../includes/invoicefunctions.php';

// Detect module name from filename.
$gatewayModuleName = basename(__FILE__, '.php');

// Fetch gateway configuration parameters.
$gatewayParams = getGatewayVariables($gatewayModuleName);


// Die if module is not active.
if (!$gatewayParams['type']) {
    die("Module Not Activated");
}


$merchantSecretKey = $gatewayParams['secretKey'];
$REFERENCE_CODE = $_POST['REFERENCE_CODE'];
$RESPONSE_CODE = $_POST['RESPONSE_CODE'];
$USE_3D = $_POST['USE_3D'];
$MERCHANT_NO = $_POST['MERCHANT_NO'];
$AUTH_CODE = $_POST['AUTH_CODE'];
$CLIENT_REFERENCE_CODE = $_POST['CLIENT_REFERENCE_CODE'];
$AUTHORIZATION_AMOUNT = $_POST['AUTHORIZATION_AMOUNT'];
$INSTALLMENT = $_POST['INSTALLMENT'];
$RND = $_POST['RND'];
$hashData = $_POST['hashData'];
$merchantSecretKey;
$order_id = explode('WHMCS', $CLIENT_REFERENCE_CODE);
$order_id = current($order_id);
$hashtr = $MERCHANT_NO . $REFERENCE_CODE . $AUTH_CODE . $RESPONSE_CODE . $USE_3D . $RND . $INSTALLMENT . $AUTHORIZATION_AMOUNT . $merchantSecretKey;
$hashDatauretilen = base64_encode(pack('H*', sha1($hashtr)));

$success = false;
if ($_POST['USE_3D'] == 'false' && $_POST['hashData'] == $hashDatauretilen) {
    if ($_POST['RESPONSE_CODE'] == 2 && $_POST['hashData'] == $hashDatauretilen) {
        $success = true;
    } else {

    }
} else {
    if ($_POST['RESPONSE_CODE'] == 2 && $_POST['hashData'] == $hashDatauretilen) {
        $response = nkolay_checkPayment($REFERENCE_CODE);
        if($response == true){
            $success = true;
        }
    }
}


$invoiceId = $order_id;
$transactionId = $CLIENT_REFERENCE_CODE;
$paymentAmount = $AUTHORIZATION_AMOUNT;
$paymentFee = 0;


$transactionStatus = $success ? 'Success' : 'Failure';


/**
 * Validate callback authenticity.
 *
 * Most payment gateways provide a method of verifying that a callback
 * originated from them. In the case of our example here, this is achieved by
 * way of a shared secret which is used to build and compare a hash.
 */
// $secretKey = $gatewayParams['secretKey'];
// if ($hash != md5($invoiceId . $transactionId . $paymentAmount . $secretKey)) {
//     $transactionStatus = 'Hash Verification Failure';
//     $success = false;
// }

/**
 * Validate Callback Invoice ID.
 *
 * Checks invoice ID is a valid invoice number. Note it will count an
 * invoice in any status as valid.
 *
 * Performs a die upon encountering an invalid Invoice ID.
 *
 * Returns a normalised invoice ID.
 *
 * @param int $invoiceId Invoice ID
 * @param string $gatewayName Gateway Name
 */
$invoiceId = checkCbInvoiceID($invoiceId, $gatewayParams['name']);

/**
 * Check Callback Transaction ID.
 *
 * Performs a check for any existing transactions with the same given
 * transaction number.
 *
 * Performs a die upon encountering a duplicate.
 *
 * @param string $transactionId Unique Transaction ID
 */
checkCbTransID($transactionId);

/**
 * Log Transaction.
 *
 * Add an entry to the Gateway Log for debugging purposes.
 *
 * The debug data can be a string or an array. In the case of an
 * array it will be
 *
 * @param string $gatewayName        Display label
 * @param string|array $debugData    Data to log
 * @param string $transactionStatus  Status
 */
logTransaction($gatewayParams['name'], $_POST, $transactionStatus);
$paymentSuccess = false;
if ($success) {

    /**
     * Add Invoice Payment.
     *
     * Applies a payment transaction entry to the given invoice ID.
     *
     * @param int $invoiceId         Invoice ID
     * @param string $transactionId  Transaction ID
     * @param float $paymentAmount   Amount paid (defaults to full balance)
     * @param float $paymentFee      Payment fee (optional)
     * @param string $gatewayModule  Gateway module name
     */
    addInvoicePayment(
        $invoiceId,
        $transactionId,
        $paymentAmount,
        $paymentFee,
        $gatewayModuleName
    );
    $paymentSuccess = true;
}


function nkolay_checkPayment($order_id)
    {
        $gatewayModuleName = basename(__FILE__, '.php');

        // Fetch gateway configuration parameters.
        $gatewayParams = getGatewayVariables($gatewayModuleName);

       
        $sandbox = $gatewayParams['testMode']; 



        $url = "https://paynkolay.nkolayislem.com.tr/Vpos/Payment/CompletePayment";

        if($sandbox == 'on'){
            $url = "https://paynkolaytest.nkolayislem.com.tr/VposNew/Payment/CompletePayment";
        }


        $ch = curl_init();
        $arrData = [
            "sx" => $gatewayParams['sxKey'],
            "referenceCode" => $order_id
        ];
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $arrData);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $server_output = curl_exec($ch);

        $result = json_decode($server_output);

        $result = json_decode($result->result);

        if ($result->RESPONSE_CODE == 2) {
            return true;
        }

        

        return false;
    }

    

    /**
 * Redirect to invoice.
 *
 * Performs redirect back to the invoice upon completion of the 3D Secure
 * process displaying the transaction result along with the invoice.
 *
 * @param int $invoiceId        Invoice ID
 * @param bool $paymentSuccess  Payment status
 */
callback3DSecureRedirect($invoiceId, $paymentSuccess);