<?php

if (!defined("WHMCS")) {
    die("This file cannot be accessed directly");
}

/**
 * Define module related meta data.
 *
 * Values returned here are used to determine module related capabilities and
 * settings.
 *
 * @see https://developers.whmcs.com/payment-gateways/meta-data-params/
 *
 * @return array
 */
function nkolay_MetaData()
{
    return array(
        'DisplayName' => 'N Kolay Öde',
        'APIVersion' => '1.1', // Use API Version 1.1
    );
}

/**
 * Define gateway configuration options.
 *
 * The fields you define here determine the configuration options that are
 * presented to administrator users when activating and configuring your
 * payment gateway module for use.
 *
 * Supported field types include:
 * * text
 * * password
 * * yesno
 * * dropdown
 * * radio
 * * textarea
 *
 * Examples of each field type and their possible configuration parameters are
 * provided in the sample function below.
 *
 * @return array
 */
function nkolay_config()
{
    return array(
        // the friendly display name for a payment gateway should be
        // defined here for backwards compatibility
        'FriendlyName' => array(
            'Type' => 'System',
            'Value' => 'N Kolay Öde',
        ),
        // a text field type allows for single line text input
        'sxKey' => array(
            'FriendlyName' => 'SX Key',
            'Type' => 'text',
            'Size' => '255',
            'Default' => '',
            'Description' => 'Enter your sx key here',
        ),
        // a password field type allows for masked text input
        'secretKey' => array(
            'FriendlyName' => 'Secret Key',
            'Type' => 'text',
            'Size' => '255',
            'Default' => '',
            'Description' => 'Enter secret key here',
        ),
        // the yesno field type displays a single checkbox option
        'threeD' => array(
            'FriendlyName' => '3D Mode',
            'Type' => 'yesno',
            'Description' => 'Tick to enable 3d mode',
        ),
        'testMode' => array(
            'FriendlyName' => 'Test Mode',
            'Type' => 'yesno',
            'Description' => 'Tick to enable test mode',
        ),

    );
}

/**
 * Payment link.
 *
 * Required by third party payment gateway modules only.
 *
 * Defines the HTML output displayed on an invoice. Typically consists of an
 * HTML form that will take the user to the payment gateway endpoint.
 *
 * @param array $params Payment Gateway Module Parameters
 *
 * @see https://developers.whmcs.com/payment-gateways/third-party-gateway/
 *
 * @return string
 */
function nkolay_link($params)
{
    // Gateway Configuration Parameters
    date_default_timezone_set("Europe/Istanbul");
    $api_key = $params['sxKey'];
    $secret_key = $params['secretKey'];

    $threed = $params['threeD'];
    $testMode = $params['testMode'];
    


    $systemUrl = $params['systemurl'];

    $sx = $api_key;
    $merchantSecretKey = $secret_key;
    $successUrl = $systemUrl . 'modules/gateways/callback/nkolay.php';
    $failUrl = $systemUrl . 'modules/gateways/callback/nkolay.php';
    $amount = $params['amount'];
    $clientRefCode = $params['invoiceid'] . 'WHMCS' . uniqid();

    $use3D = $threed == 'on' ? 'true' : 'false'; 
    $rnd = date("d.m.Y H:i:s");
    $detail = "false";
    $transactionType = "SALES";

    $hashstr = $sx . $clientRefCode . $amount . $successUrl . $failUrl . $rnd . $merchantSecretKey; 
    
    $hashData = base64_encode(pack('H*',sha1($hashstr)));
    $url = "https://paynkolay.nkolayislem.com.tr/Vpos";

    if($testMode == 'on'){
        $url = "https://paynkolaytest.nkolayislem.com.tr/VposNew";
    }
    $data['data'] = [
        'sx' => $sx,
        'successUrl' => $successUrl,
        'failUrl' => $failUrl,
        'amount' => $amount,
        'clientRefCode' => $clientRefCode,

        'use3D' => $use3D,
        'rnd' => $rnd,

        'detail' => $detail,
        'transactionType' => $transactionType,
        'hashData' => $hashData,
    ];

    $form = "<form method='post' action='" . $url . "'>";
    foreach($data['data'] as $key => $value){
        $form .= "<input type='hidden' name='". $key ."' value='". $value ."'>";
    }
    $form .= '<button type="submit" class="btn btn-primary">' . $params['langpaynow'].'</button></form>';
    return $form;
    //echo $form;

}

/**
 * @param $params
 * @return array|false
 */
function nkolay_refund($params)
{

}